@@ -1,7 +1,7 @@
 package Redis::hiredis;
 
 use strict;
-our $VERSION = "0.0.3";
+our $VERSION = "0.9.2";
 require XSLoader;
 XSLoader::load('Redis::hiredis', $VERSION);
 
@@ -17,8 +17,8 @@ Redis::hiredis - interact with Redis using the hiredis client.
   use Redis::hiredis;
   my $redis = Redis::hiredis->new();
   $redis->connect('127.0.0.1', 6379);
-  $redis->command([qw(set foo bar)]);
-  my $val = $redis->command([qw(get foo)]);
+  $redis->command('set foo bar');
+  my $val = $redis->command('get foo');
 
 =head1 DESCRIPTION
 
@@ -26,6 +26,8 @@ C<Redis::hiredis> is a simple wrapper around Salvatore Sanfilippo's
 hiredis C client that allows connecting and sending any command
 just like you would from a command line Redis client.
 
+B<NOTE> Versions >= 0.9.2 are not compatible with prior versions
+
 =head2 METHODS
 
 =over 4
@@ -42,10 +44,10 @@ C<$port> is the port to connect on.  Default 6379
 
 =item command( $command )
 
-C<$command> is an array ref of the command and parameters you would like
-to send to Redis ex:
+C<$command> is a string identical to what you would pass using 
+the official redis cli
 
-  [qw( set foo bar )]
+  'set foo bar'
 
 command will return a scalar value which will either be an integer, string
 or an array ref (if multiple values are returned).
